# Generated by Django 5.1.7 on 2025-03-12 16:24

import tinymce.models
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="EmailConfiguration",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "activated",
                    models.BooleanField(
                        default=False,
                        help_text="Só ative essa opção depois de testar as configurações de email no botão ao lado. Quando ativado, as notificações vão ser enviadas por email e será possível a usuários redefinir suas senhas.",
                        verbose_name="Email está ativado?",
                    ),
                ),
                (
                    "host",
                    models.CharField(
                        default="smtp.gmail.com", max_length=128, verbose_name="Host"
                    ),
                ),
                (
                    "port",
                    models.PositiveIntegerField(default=587, verbose_name="Porta"),
                ),
                (
                    "username",
                    models.CharField(
                        default="example@gmail.com",
                        max_length=128,
                        verbose_name="Usuário",
                    ),
                ),
                (
                    "password",
                    models.CharField(
                        default="1234", max_length=128, verbose_name="Senha"
                    ),
                ),
                ("use_tls", models.BooleanField(default=True, verbose_name="Usar TLS")),
                (
                    "use_ssl",
                    models.BooleanField(default=False, verbose_name="Usar SSL"),
                ),
                (
                    "timeout",
                    models.IntegerField(
                        blank=True, default=120, null=True, verbose_name="Timeout"
                    ),
                ),
                (
                    "from_name",
                    models.CharField(
                        blank=True,
                        max_length=255,
                        null=True,
                        verbose_name="Nome do remetente",
                    ),
                ),
                (
                    "from_email",
                    models.EmailField(
                        default="admin@example.com",
                        max_length=254,
                        verbose_name="Email remetente",
                    ),
                ),
                (
                    "signature",
                    tinymce.models.HTMLField(
                        blank=True,
                        help_text="Para usar essa assinatura em seus emails, utilize a variável <code>{{ signature }}</code>.",
                        null=True,
                        verbose_name="Assinatura dos emails",
                    ),
                ),
            ],
            options={
                "verbose_name": "Email configuration",
            },
        ),
    ]



from typing import override

from django.db import models
from django.utils.html import format_html
from django.utils.translation import gettext_lazy as _
from solo.models import SingletonModel
from tinymce.models import HTMLField


class EmailConfiguration(SingletonModel):
    activated = models.BooleanField(
        default=False,
        verbose_name=_("Email está ativado?"),
        help_text=_(
            "Só ative essa opção depois de testar as configurações de "
            + "email no botão ao lado. Quando ativado, as notificações vão "
            + "ser enviadas por email e será possível a usuários "
            + "redefinir suas senhas."
        ),
    )
    host = models.CharField(
        max_length=128,
        verbose_name=_("Host"),
        default="smtp.gmail.com",
    )
    port = models.PositiveIntegerField(
        verbose_name=_("Porta"),
        default=587,
    )
    username = models.CharField(
        max_length=128,
        verbose_name=_("Usuário"),
        default="example@gmail.com",
    )
    password = models.CharField(
        max_length=128,
        verbose_name=_("Senha"),
        default="1234",
    )
    use_tls = models.BooleanField(
        default=True,
        verbose_name=_("Usar TLS"),
    )
    use_ssl = models.BooleanField(
        default=False,
        verbose_name=_("Usar SSL"),
    )
    timeout = models.IntegerField(
        blank=True,
        null=True,
        default=120,
        verbose_name=_("Timeout"),
    )
    from_name = models.CharField(
        max_length=255,
        verbose_name=_("Nome do remetente"),
        null=True,
        blank=True,
    )
    from_email = models.EmailField(
        verbose_name=_("Email remetente"),
        default="admin@example.com",
    )
    signature = HTMLField(
        blank=True,
        null=True,
        verbose_name=_("Assinatura dos emails"),
        help_text=format_html(
            "{}<code>{}</code>{}",
            _("Para usar essa assinatura em seus emails, utilize a variável "),
            "{{ signature }}",
            ".",
        ),
    )

    @override
    def __str__(self):
        return str(self._meta.verbose_name)

    class Meta:
        verbose_name = _("Email configuration")



from smtplib import SMTPException

from django.contrib import admin, messages
from django.core import mail
from django.core.mail.backends.console import EmailBackend as ConsoleEmailBackend
from django.http import HttpRequest
from django.utils.translation import gettext_lazy as _
from django_object_actions import DjangoObjectActions, action
from solo.admin import SingletonModelAdmin

from .models import EmailConfiguration


@admin.register(EmailConfiguration)
class EmailConfigurationAdmin(DjangoObjectActions, SingletonModelAdmin):
    change_actions = ["test_email"]

    @action(
        label=_("Test email"),
        description=_(
            "Send a test email from the account configured below to the "
            "email registered as sender. Save before using."
        ),
    )
    def test_email(self, request: HttpRequest, obj: EmailConfiguration):
        host = request.get_host()
        try:
            with mail.get_connection() as connection:
                if type(connection) is ConsoleEmailBackend:
                    raise AssertionError(
                        _("Using debug backend. Try using DEBUG=False in settings")
                    )
                __ = mail.send_mail(
                    message=_(
                        "This email has been sent to verify if the "
                        "mailing system is well configured in the "
                        "%(host)s's administration. It seems so!"
                    )
                    % {"host": host},
                    from_email=obj.from_email,
                    subject=_("[%(host)s] Email test") % {"host": host},
                    recipient_list=[obj.from_email],
                    fail_silently=False,
                    connection=connection,
                )
        except (SMTPException, AssertionError) as e:
            messages.error(
                request,
                _("Email not well configured: %s") % str(e),
            )
            return

        messages.success(
            request,
            _("Email is well configured! :)"),
        )
